pitchtools.chromatic_pitch_name_to_chromatic_pitch_class_number
===============================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_name_to_chromatic_pitch_class_number
